@@ -21,7 +21,7 @@ from collections import Sequence, MutableMapping, Iterable, namedtuple, \
 from xonsh.tools import suggest_commands, XonshError, ON_POSIX, ON_WINDOWS, \
     string_types
 from xonsh.inspectors import Inspector
-from xonsh.environ import Env, default_env
+from xonsh.environ import Env, default_env, locate_binary
 from xonsh.aliases import DEFAULT_ALIASES
 from xonsh.jobs import add_job, wait_for_active_job
 from xonsh.proc import ProcProxy, SimpleProcProxy, TeePTYProc
@@ -521,8 +521,16 @@ def run_subproc(cmds, captured=True):
         # set standard error
         if 'stderr' in streams:
             stderr = streams['stderr']
-        uninew = ix == last_cmd
+        uninew = (ix == last_cmd) and (not captured)
         alias = builtins.aliases.get(cmd[0], None)
+        if (alias is None
+            and builtins.__xonsh_env__.get('AUTO_CD')
+            and len(cmds)==1
+            and os.path.isdir(cmd[0])
+            and locate_binary(cmd[0], cwd=None) is None):
+            cmd.insert(0, 'cd')
+            alias = builtins.aliases.get('cd', None)
+
         if callable(alias):
             aliased_cmd = alias
         else:
@@ -604,6 +612,11 @@ def run_subproc(cmds, captured=True):
         if prev_proc.stdout not in (None, sys.stdout):
             output = prev_proc.stdout.read()
         if captured:
+            # to get proper encoding from Popen, we have to 
+            # use a byte stream and then implement universal_newlines here
+            output = output.decode(encoding=ENV.get('XONSH_ENCODING'),
+                                   errors=ENV.get('XONSH_ENCODING_ERRORS'))
+            output = output.replace('\r\n', '\n')
             return output
         else:
             hist.last_cmd_out = output
@@ -646,6 +659,7 @@ def load_builtins(execer=None):
     builtins.__xonsh_superhelp__ = superhelper
     builtins.__xonsh_regexpath__ = regexpath
     builtins.__xonsh_glob__ = globpath
+    builtins.__xonsh_expand_path__ = expand_path
     builtins.__xonsh_exit__ = False
     if hasattr(builtins, 'exit'):
         builtins.__xonsh_pyexit__ = builtins.exit
@@ -696,6 +710,7 @@ def unload_builtins():
              '__xonsh_superhelp__',
              '__xonsh_regexpath__',
              '__xonsh_glob__',
+             '__xonsh_expand_path__',
              '__xonsh_exit__',
              '__xonsh_pyexit__',
              '__xonsh_pyquit__',
