@@ -37,6 +37,8 @@ COMP_CWORD={n}
 for ((i=0;i<${{#COMPREPLY[*]}};i++)) do echo ${{COMPREPLY[i]}}; done
 """
 
+WS = set(' \t\r\n')
+
 def startswithlow(x, start, startlow=None):
     """True if x starts with a string or its lowercase version. The lowercase
     version may be optionally be provided.
@@ -94,7 +96,7 @@ class Completer(object):
             self.have_bash = False
 
     def complete(self, prefix, line, begidx, endidx, ctx=None):
-        """Complete the string s, given a possible execution context.
+        """Complete the string, given a possible execution context.
 
         Parameters
         ----------
@@ -165,6 +167,41 @@ class Completer(object):
         rtn |= self.path_complete(prefix)
         return sorted(rtn)
 
+    def find_and_complete(self, line, idx, ctx=None):
+        """Finds the completions given only the full code line and a current cursor
+        position. This represents an easier alternative to the complete() method.
+
+        Parameters
+        ----------
+        line : str
+            The line that prefix appears on.
+        idx : int
+            The current position in the line.
+        ctx : Iterable of str (ie dict, set, etc), optional
+            Names in the current execution context.
+
+        Returns
+        -------
+        rtn : list of str
+            Possible completions of prefix, sorted alphabetically.
+        begidx : int
+            The index in line that prefix starts on.
+        endidx : int
+            The index in line that prefix ends on.
+        """
+        if idx < 0:
+            raise ValueError('index must be non-negative!')
+        n = len(line)
+        begidx = endidx = (idx - 1 if idx == n else idx)
+        while 0 < begidx and line[begidx] not in WS:
+            begidx -= 1
+        begidx = begidx + 1 if line[begidx] in WS else begidx
+        while endidx < n - 1 and line[endidx] not in WS:
+            endidx += 1
+        endidx = endidx - 1 if line[endidx] in WS else endidx
+        prefix = line[begidx:endidx+1]
+        return self.complete(prefix, line, begidx, endidx, ctx=ctx), begidx, endidx
+
     def _add_env(self, paths, prefix):
         if prefix.startswith('$'):
             csc = builtins.__xonsh_env__.get('CASE_SENSITIVE_COMPLETIONS')
@@ -346,7 +383,7 @@ class Completer(object):
             csc = builtins.__xonsh_env__.get('CASE_SENSITIVE_COMPLETIONS')
             startswither = startswithnorm if csc else startswithlow
             attrlow = attr.lower()
-            opts = [o for o in opts if startswither(o, attrlow)]
+            opts = [o for o in opts if startswither(o, attr, attrlow)]
         prelen = len(prefix)
         for opt in opts:
             a = getattr(val, opt)
