@@ -12,10 +12,13 @@ from functools import wraps
 from collections import MutableMapping, MutableSequence, MutableSet, namedtuple
 
 from xonsh import __version__ as XONSH_VERSION
-from xonsh.tools import TERM_COLORS, ON_WINDOWS, ON_MAC, ON_LINUX, string_types, \
-    is_int, always_true, always_false, ensure_string, is_env_path, str_to_env_path, \
-    env_path_to_str, is_bool, to_bool, bool_to_str, is_history_tuple, to_history_tuple, \
-    history_tuple_to_str, is_float
+from xonsh.tools import (
+    TERM_COLORS, ON_WINDOWS, ON_MAC, ON_LINUX, ON_ARCH, IS_ROOT,
+    always_true, always_false, ensure_string, is_env_path, str_to_env_path,
+    env_path_to_str, is_bool, to_bool, bool_to_str, is_history_tuple, to_history_tuple,
+    history_tuple_to_str, is_float, string_types, is_string, DEFAULT_ENCODING,
+    is_completions_display_value, to_completions_display_value
+)
 from xonsh.dirstack import _get_cwd
 from xonsh.foreign_shells import DEFAULT_SHELLS, load_foreign_envs
 
@@ -26,10 +29,8 @@ LOCALE_CATS = {
     'LC_MONETARY': locale.LC_MONETARY,
     'LC_TIME': locale.LC_TIME,
 }
-try:
+if hasattr(locale, 'LC_MESSAGES'):
     LOCALE_CATS['LC_MESSAGES'] = locale.LC_MESSAGES
-except AttributeError:
-    pass
 
 
 def locale_convert(key):
@@ -49,19 +50,26 @@ represent environment variable validation, conversion, detyping.
 """
 
 DEFAULT_ENSURERS = {
-    re.compile('\w*PATH'): (is_env_path, str_to_env_path, env_path_to_str),
+    'AUTO_CD': (is_bool, to_bool, bool_to_str), 
+    'AUTO_SUGGEST': (is_bool, to_bool, bool_to_str),
+    'BASH_COMPLETIONS': (is_env_path, str_to_env_path, env_path_to_str),
+    'CASE_SENSITIVE_COMPLETIONS': (is_bool, to_bool, bool_to_str),
     re.compile('\w*DIRS'): (is_env_path, str_to_env_path, env_path_to_str),
+    'COMPLETIONS_DISPLAY': (is_completions_display_value, to_completions_display_value, str),
+    'LC_COLLATE': (always_false, locale_convert('LC_COLLATE'), ensure_string),
     'LC_CTYPE': (always_false, locale_convert('LC_CTYPE'), ensure_string),
     'LC_MESSAGES': (always_false, locale_convert('LC_MESSAGES'), ensure_string),
-    'LC_COLLATE': (always_false, locale_convert('LC_COLLATE'), ensure_string),
-    'LC_NUMERIC': (always_false, locale_convert('LC_NUMERIC'), ensure_string),
     'LC_MONETARY': (always_false, locale_convert('LC_MONETARY'), ensure_string),
+    'LC_NUMERIC': (always_false, locale_convert('LC_NUMERIC'), ensure_string),
     'LC_TIME': (always_false, locale_convert('LC_TIME'), ensure_string),
+    'MOUSE_SUPPORT': (is_bool, to_bool, bool_to_str),
+    re.compile('\w*PATH'): (is_env_path, str_to_env_path, env_path_to_str),
+    'TEEPTY_PIPE_DELAY': (is_float, float, str),
+    'XONSHRC': (is_env_path, str_to_env_path, env_path_to_str),
+    'XONSH_ENCODING': (is_string, ensure_string, ensure_string),
+    'XONSH_ENCODING_ERRORS': (is_string, ensure_string, ensure_string),
     'XONSH_HISTORY_SIZE': (is_history_tuple, to_history_tuple, history_tuple_to_str),
     'XONSH_STORE_STDOUT': (is_bool, to_bool, bool_to_str),
-    'CASE_SENSITIVE_COMPLETIONS': (is_bool, to_bool, bool_to_str),
-    'BASH_COMPLETIONS': (is_env_path, str_to_env_path, env_path_to_str),
-    'TEEPTY_PIPE_DELAY': (is_float, float, str),
 }
 
 #
@@ -75,10 +83,10 @@ def default_value(f):
 def is_callable_default(x):
     """Checks if a value is a callable default."""
     return callable(x) and getattr(x, '_xonsh_callable_default', False)
-    
+
 DEFAULT_PROMPT = ('{BOLD_GREEN}{user}@{hostname}{BOLD_BLUE} '
                   '{cwd}{branch_color}{curr_branch} '
-                  '{BOLD_BLUE}${NO_COLOR} ')
+                  '{BOLD_BLUE}{prompt_end}{NO_COLOR} ')
 DEFAULT_TITLE = '{user}@{hostname}: {cwd} | xonsh'
 
 @default_value
@@ -109,13 +117,20 @@ def xonshconfig(env):
 # to set them they have to do a copy and write them to the environment.
 # try to keep this sorted.
 DEFAULT_VALUES = {
+    'AUTO_CD': False,                 
     'AUTO_PUSHD': False,
-    'BASH_COMPLETIONS': ('/usr/local/etc/bash_completion',
-                         '/opt/local/etc/profile.d/bash_completion.sh') if ON_MAC \
-                        else ('/etc/bash_completion', 
-                              '/usr/share/bash-completion/completions/git'),
+    'AUTO_SUGGEST': True,
+    'BASH_COMPLETIONS': (('/usr/local/etc/bash_completion',
+                             '/opt/local/etc/profile.d/bash_completion.sh')
+                        if ON_MAC else
+                        ('/usr/share/bash-completion/bash_completion',
+                             '/usr/share/bash-completion/completions/git') 
+                        if ON_ARCH else
+                        ('/etc/bash_completion',
+                             '/usr/share/bash-completion/completions/git')),
     'CASE_SENSITIVE_COMPLETIONS': ON_LINUX,
     'CDPATH': (),
+    'COMPLETIONS_DISPLAY': 'multi',
     'DIRSTACK_SIZE': 20,
     'FORCE_POSIX_PATHS': False,
     'INDENT': '    ',
@@ -124,6 +139,7 @@ DEFAULT_VALUES = {
     'LC_TIME': locale.setlocale(locale.LC_TIME),
     'LC_MONETARY': locale.setlocale(locale.LC_MONETARY),
     'LC_NUMERIC': locale.setlocale(locale.LC_NUMERIC),
+    'MOUSE_SUPPORT': False,
     'MULTILINE_PROMPT': '.',
     'PATH': (),
     'PATHEXT': (),
@@ -140,14 +156,21 @@ DEFAULT_VALUES = {
     'XDG_CONFIG_HOME': os.path.expanduser(os.path.join('~', '.config')),
     'XDG_DATA_HOME': os.path.expanduser(os.path.join('~', '.local', 'share')),
     'XONSHCONFIG': xonshconfig,
-    'XONSHRC': os.path.expanduser('~/.xonshrc'),
+    'XONSHRC': ((os.path.join(os.environ['ALLUSERSPROFILE'],
+                              'xonsh', 'xonshrc'),
+                os.path.expanduser('~/.xonshrc')) if ON_WINDOWS
+               else ('/etc/xonshrc', os.path.expanduser('~/.xonshrc'))), 
     'XONSH_CONFIG_DIR': xonsh_config_dir,
     'XONSH_DATA_DIR': xonsh_data_dir,
+    'XONSH_ENCODING': DEFAULT_ENCODING,
+    'XONSH_ENCODING_ERRORS': 'surrogateescape',
     'XONSH_HISTORY_FILE': os.path.expanduser('~/.xonsh_history.json'),
     'XONSH_HISTORY_SIZE': (8128, 'commands'),
     'XONSH_SHOW_TRACEBACK': False,
     'XONSH_STORE_STDOUT': False,
 }
+if hasattr(locale, 'LC_MESSAGES'):
+    DEFAULT_VALUES['LC_MESSAGES'] = locale.setlocale(locale.LC_MESSAGES)
 
 class DefaultNotGivenType(object):
     """Singleton for representing when no default value is given."""
@@ -518,6 +541,7 @@ else:
 
 FORMATTER_DICT = dict(
     user=os.environ.get(USER, '<user>'),
+    prompt_end='#' if IS_ROOT else '$',
     hostname=socket.gethostname().split('.', 1)[0],
     cwd=_replace_home_cwd,
     cwd_dir=lambda: os.path.dirname(_replace_home_cwd()),
@@ -575,26 +599,15 @@ def multiline_prompt():
 BASE_ENV = {
     'BASH_COMPLETIONS': list(DEFAULT_VALUES['BASH_COMPLETIONS']),
     'FORMATTER_DICT': dict(DEFAULT_VALUES['FORMATTER_DICT']),
-    'LC_CTYPE': locale.setlocale(locale.LC_CTYPE),
-    'LC_COLLATE': locale.setlocale(locale.LC_COLLATE),
-    'LC_TIME': locale.setlocale(locale.LC_TIME),
-    'LC_MONETARY': locale.setlocale(locale.LC_MONETARY),
-    'LC_NUMERIC': locale.setlocale(locale.LC_NUMERIC),
     'XONSH_VERSION': XONSH_VERSION,
 }
 
-try:
-    BASE_ENV['LC_MESSAGES'] = DEFAULT_VALUES['LC_MESSAGES'] = \
-        locale.setlocale(locale.LC_MESSAGES)
-except AttributeError:
-    pass
-
 def load_static_config(ctx):
-    """Loads a static configuration file from a given context, rather than the 
+    """Loads a static configuration file from a given context, rather than the
     current environment.
     """
     env = {}
-    env['XDG_CONFIG_HOME'] = ctx.get('XDG_CONFIG_HOME', 
+    env['XDG_CONFIG_HOME'] = ctx.get('XDG_CONFIG_HOME',
                                      DEFAULT_VALUES['XDG_CONFIG_HOME'])
     env['XONSH_CONFIG_DIR'] = ctx['XONSH_CONFIG_DIR'] if 'XONSH_CONFIG_DIR' in ctx \
                               else xonsh_config_dir(env)
@@ -609,24 +622,28 @@ def load_static_config(ctx):
     return conf
 
 
-def xonshrc_context(rcfile=None, execer=None):
+def xonshrc_context(rcfiles=None, execer=None):
     """Attempts to read in xonshrc file, and return the contents."""
-    if rcfile is None or execer is None or not os.path.isfile(rcfile):
+    if (rcfiles is None or execer is None
+       or sum([os.path.isfile(rcfile) for rcfile in rcfiles]) == 0):
         return {}
-    with open(rcfile, 'r') as f:
-        rc = f.read()
-    if not rc.endswith('\n'):
-        rc += '\n'
-    fname = execer.filename
     env = {}
-    try:
-        execer.filename = rcfile
-        execer.exec(rc, glbs=env)
-    except SyntaxError as err:
-        msg = 'syntax error in xonsh run control file {0!r}: {1!s}'
-        warn(msg.format(rcfile, err), RuntimeWarning)
-    finally:
-        execer.filename = fname
+    for rcfile in rcfiles:
+        if not os.path.isfile(rcfile):
+            continue
+        with open(rcfile, 'r') as f:
+            rc = f.read()
+        if not rc.endswith('\n'):
+            rc += '\n'
+        fname = execer.filename
+        try:
+            execer.filename = rcfile
+            execer.exec(rc, glbs=env)
+        except SyntaxError as err:
+            msg = 'syntax error in xonsh run control file {0!r}: {1!s}'
+            warn(msg.format(rcfile, err), RuntimeWarning)
+        finally:
+            execer.filename = fname
     return env
 
 
@@ -656,7 +673,7 @@ def default_env(env=None):
     ctx.update(os.environ)
     conf = load_static_config(ctx)
     ctx.update(conf.get('env', ()))
-    ctx.update(load_foreign_envs(shells=conf.get('foreign_shells', DEFAULT_SHELLS), 
+    ctx.update(load_foreign_envs(shells=conf.get('foreign_shells', DEFAULT_SHELLS),
                                  issue_warning=False))
     if ON_WINDOWS:
         windows_env_fixes(ctx)
