@@ -16,6 +16,7 @@ Implementations:
 * indent()
 
 """
+import ctypes
 import os
 import re
 import sys
@@ -24,10 +25,9 @@ import platform
 import traceback
 import threading
 import subprocess
-from itertools import zip_longest
 from contextlib import contextmanager
 from collections import OrderedDict, Sequence
-
+from warnings import warn
 
 if sys.version_info[0] >= 3:
     string_types = (str, bytes)
@@ -41,7 +41,9 @@ DEFAULT_ENCODING = sys.getdefaultencoding()
 ON_WINDOWS = (platform.system() == 'Windows')
 ON_MAC = (platform.system() == 'Darwin')
 ON_LINUX = (platform.system() == 'Linux')
+ON_ARCH = (platform.linux_distribution()[0] == 'arch')
 ON_POSIX = (os.name == 'posix')
+IS_ROOT = ctypes.windll.shell32.IsUserAnAdmin() != 0 if ON_WINDOWS else os.getuid() == 0
 
 VER_3_4 = (3, 4)
 VER_3_5 = (3, 5)
@@ -474,6 +476,11 @@ def is_float(x):
     return isinstance(x, float)
 
 
+def is_string(x):
+    """Tests if something is a string"""
+    return isinstance(x, string_types)
+
+
 def always_true(x):
     """Returns True"""
     return True
@@ -549,6 +556,25 @@ def ensure_int_or_slice(x):
         return int(x)
 
 
+def is_completions_display_value(x):
+    return x in {'none', 'single', 'multi'}
+
+
+def to_completions_display_value(x):
+    x = str(x).lower()
+    if x in {'none', 'false'}:
+        x = 'none'
+    elif x in {'multi', 'true'}:
+        x = 'multi'
+    elif x in {'single'}:
+        x = 'single'
+    else:
+        warn('"{}" is not a valid value for $COMPLETIONS_DISPLAY. '.format(x) +
+             'Using "multi".', RuntimeWarning)
+        x = 'multi'
+    return x
+
+
 # history validation
 
 _min_to_sec = lambda x: 60.0 * float(x)
